//
//  PokedexModel.swift
//  Pokedex
//
//  Created by Santiago Pavón on 30/09/16.
//  Copyright (c) 2016 UPM. All rights reserved.
//

import Foundation

/// Modelo de datos de los pokemons.
/// Tiene información sobre las razas y los tipos de pokemons.
class PokedexModel {
    
    /// Array de objetos Race.
    var races = [Race]()
    
    /// Array de objetos Type.
    var types = [Type]()
    
    /// Carga los datos de pokemons.plist en las propiedades races y types.
    init() {
        guard let url = Bundle.main.url(forResource: "pokemons",
                                        withExtension: "plist"),
            let plist = NSDictionary(contentsOf: url) as? [String:Any],
            let allNames = plist["nombres"] as? [String:String],
            let allIcons = plist["iconos"]  as? [String:String],
            let allTypes = plist["tipos"]   as? [String:[Int]] else { return }

        races = allNames.map({ (code, name) in
            Race(code: code, name: name, icon: allIcons[code]!)
        }).sorted(by: { $0.name < $1.name })
        
        types = allTypes.map({ (name, raceCodes) in
            Type(name: name,
                 races: races.filter({ (race) -> Bool in
                    raceCodes.contains(where: { "\($0)" == race.code })
                 }).sorted(by: { $0.name < $1.name }) )
        }).sorted(by: { $0.name < $1.name })
    }
}




